==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/CONTACTINFOEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTACTINFOEQUIPMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTACTINFOEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTACTINFOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTACTINFOEQUIPMENTID_Type", propOrder = {
    "contactinfoid",
    "equipmentid"
})
public class CONTACTINFOEQUIPMENTID_Type {

    @XmlElement(name = "CONTACTINFOID", required = true)
    protected CONTACTINFOID_Type contactinfoid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Obtient la valeur de la propriété contactinfoid.
     * 
     * @return
     *     possible object is
     *     {@link CONTACTINFOID_Type }
     *     
     */
    public CONTACTINFOID_Type getCONTACTINFOID() {
        return contactinfoid;
    }

    /**
     * Définit la valeur de la propriété contactinfoid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTACTINFOID_Type }
     *     
     */
    public void setCONTACTINFOID(CONTACTINFOID_Type value) {
        this.contactinfoid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/CONTACTINFOEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTACTINFOEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTACTINFOEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTACTINFOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTACTINFOEQUIPMENTID_Type", propOrder = {
    "contactinfoid",
    "equipmentid"
})
public class CONTACTINFOEQUIPMENTID_Type {

    @XmlElement(name = "CONTACTINFOID", required = true)
    protected CONTACTINFOID_Type contactinfoid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Gets the value of the contactinfoid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTACTINFOID_Type }
     *     
     */
    public CONTACTINFOID_Type getCONTACTINFOID() {
        return contactinfoid;
    }

    /**
     * Sets the value of the contactinfoid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTACTINFOID_Type }
     *     
     */
    public void setCONTACTINFOID(CONTACTINFOID_Type value) {
        this.contactinfoid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}
